#creating MathOperation module
#the module provides addition, subtraction, multiplication, and division functions

#all the functions take two numbers as argument
#creating addition function

#class akpycalc1:
#    def __init__(self) -> None:

def add(num1,num2):
    return num1+num2


add()